@@ -9,7 +9,7 @@
 @Desc    :   None
 '''
 
-from config.load_config import ConfigUtil
+from sw_ops_common.config.load_config import ConfigUtil
 
 
 class Settings:
